@@ -30,7 +30,7 @@ import re
 sys.path.insert(0, os.path.dirname(__file__) + '/..')
 
 from monkeysign.gpg import *
-from test_lib import find_test_file, skipUnlessUnicodeLocale
+from test_lib import find_test_file, skipUnlessUnicodeLocale, skipIfDatePassed
 
 class TestContext(unittest.TestCase):
     """Tests for the Context class.
@@ -224,12 +224,14 @@ class TestKeyringWithKeys(TestKeyringBase):
         with self.assertRaises(GpgRuntimeError):
             self.gpg.sign_key('7B75921E', True)
 
+    @skipIfDatePassed('2017-06-01T00:00:00UTC')
     def test_sign_key_all_uids(self):
         """test signature of all uids of a key"""
         self.assertTrue(self.gpg.sign_key('7B75921E', True))
         self.gpg.context.call_command(['list-sigs', '7B75921E'])
         self.assertRegexpMatches(self.gpg.context.stdout, 'sig:::1:86E4E70A96F47C6A:[^:]*::::Second Test Key <unittests@monkeysphere.info>:10x:')
 
+    @skipIfDatePassed('2017-06-01T00:00:00UTC')
     def test_sign_key_single_uid(self):
         """test signing a key with a single uid"""
         self.assertTrue(self.gpg.import_data(open(find_test_file('323F39BD.asc')).read()))
@@ -244,6 +246,7 @@ class TestKeyringWithKeys(TestKeyringBase):
         self.gpg.context.call_command(['list-sigs', '7B75921E'])
         self.assertRegexpMatches(self.gpg.context.stdout, 'sig:::1:86E4E70A96F47C6A:[^:]*::::Second Test Key <unittests@monkeysphere.info>:10x:')
 
+    @skipIfDatePassed('2017-06-01T00:00:00UTC')
     def test_sign_key_as_user(self):
         """normal signature with a signing user specified"""
         self.gpg.context.set_option('local-user', '96F47C6A')
@@ -352,6 +355,7 @@ class TestKeyringWithAbnormalKeys(TestKeyringBase):
         self.assertTrue(self.gpg.import_data(open(find_test_file('96F47C6A.asc')).read()))
         self.assertTrue(self.gpg.import_data(open(find_test_file('96F47C6A-secret.asc')).read()))
 
+    @skipIfDatePassed('2018-02-03T00:00:00UTC')
     def test_wrongly_place_sigs(self):
         """test zack's key
 
