@@ -33,7 +33,10 @@ import tempfile
 try:
     from unittest.mock import Mock
 except ImportError:
-    from mock import Mock
+    try:
+        from mock import Mock
+    except:
+        Mock = False
 
 def which2(cmd):
     """naive implementation of which for Python 2"""
@@ -59,7 +62,7 @@ from monkeysign.gpg import TempKeyring, GpgRuntimeError
 
 import test_lib
 # optimized because called often
-from test_lib import find_test_file
+from test_lib import find_test_file, skipIfDatePassed, skipUnlessNetwork
 
 
 class CliBaseTest(unittest.TestCase):
@@ -114,6 +117,8 @@ class CliBaseTest(unittest.TestCase):
     def tearDown(self):
         sys.argv = self.argv
 
+
+@unittest.skipUnless(Mock, 'mock library missing')
 class CliTestCase(CliBaseTest):
     def setUp(self):
         CliBaseTest.setUp(self)
@@ -181,6 +186,7 @@ class CliTestCase(CliBaseTest):
         self.assertTrue(args.local)
 
 
+@skipIfDatePassed('2017-06-01T00:00:00UTC')
 class CliTestDialog(CliBaseTest):
     def setUp(self):
         CliBaseTest.setUp(self)
@@ -216,6 +222,8 @@ this tests for bug #716675"""
                 self.execute()
         self.write_to_callback("\n\n", callback) # say 'default' twice
 
+
+@skipIfDatePassed('2017-06-01T00:00:00UTC')
 class CliTestSpacedFingerprint(CliTestDialog):
     def setUp(self):
         CliTestDialog.setUp(self)
@@ -245,6 +253,8 @@ class BasicTests(BaseTestCase):
         del self.ui
         self.assertFalse(os.path.exists(self.homedir))
 
+
+@skipIfDatePassed('2017-06-01T00:00:00UTC')
 class SigningTests(BaseTestCase):
     pattern = '7B75921E'
 
@@ -401,6 +411,8 @@ this duplicates tests from the gpg code, but is necessary to test later function
             self.assertIn(EmailFactory.body, contents)
         os.unlink(outputfile)
 
+
+@skipIfDatePassed('2017-06-01T00:00:00UTC')
 class EmailFactoryTest(BaseTestCase):
     pattern = '7B75921E'
 
@@ -493,6 +505,8 @@ class FakeKeyringTests(BaseTestCase):
         """test if we can find a key on the local keyring"""
         self.ui.find_key()
 
+
+@skipUnlessNetwork()
 class NonExistentKeyTests(BaseTestCase, test_lib.TestTimeLimit):
     """test behavior with a key that can't be found"""
 
@@ -508,5 +522,16 @@ class NonExistentKeyTests(BaseTestCase, test_lib.TestTimeLimit):
         except test_lib.AlarmException:
             raise unittest.case._ExpectedFailure(sys.exc_info())
 
+
+@skipUnlessNetwork()
+class KeyserverTests(BaseTestCase):
+    args = ['--keyserver', 'pool.sks-keyservers.net']
+    pattern = '7B75921E'
+
+    def test_find_key(self):
+        """this should find the key on the keyservers"""
+        self.ui.find_key()
+
+
 if __name__ == '__main__':
     unittest.main()
