@@ -48,6 +48,7 @@ except ImportError:
     from pipes import quote as cmd_quote
 import shutil
 import socket
+import socks
 import tempfile
 
 
@@ -126,6 +127,10 @@ class MonkeysignArgumentParser(argparse.ArgumentParser):
                                    'certification'))
         self.add_argument('-k', '--keyserver',
                             help=_('keyserver to fetch keys from'))
+        self.add_argument('--tor', action='store_true',
+                          help=_('use Tor to get keys and send email'))
+        self.add_argument('--socks', metavar='HOST[:PORT]',
+                          help=_('connect to SOCKS proxy'))
         self.add_argument('-s', '--smtpserver', '--smtp',
                             help=_('SMTP server to use, use a colon to specify '
                                    'the port number if non-default (%(port)d).'
@@ -217,6 +222,17 @@ class MonkeysignArgumentParser(argparse.ArgumentParser):
             self.save_config(args)
         if args.local:
             args.nomail = True
+        if args.tor and args.socks:
+            self.error('specify only one of --tor or --socks')
+        if args.tor:
+            args.socks = 'localhost:9050'
+        if args.socks:
+            args.socks = args.socks.split(':')
+            if len(args.socks) < 2:
+                # hardcode default port number
+                args.socks += [socks.DEFAULT_PORTS[socks.SOCKS5]]
+            args.socks[1] = int(args.socks[1])
+            args.socks = tuple(args.socks)
         return args
 
     def save_config(self, args, config=None, close=True):
@@ -391,6 +407,28 @@ configuration files are parsed by default: %s"""
             self.tmpkeyring.context.set_option('default-cert-level', self.options.certlevel)
         self.tmpkeyring.context.set_option('secret-keyring', self.keyring.homedir + '/secring.gpg')
 
+        if self.options.socks:
+            # test if tor is running, as a safety precaution
+            try:
+                s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+                s.connect(self.options.socks)
+                s.close()
+            except socket.error as e:
+                m = list(self.options.socks)
+                if self.options.tor:
+                    m += [str(e) + _(' - is Tor running?')]
+                else:
+                    m += [str(e)]
+                self.abort(_('cannot open SOCKS proxy %s:%d: %s') % m)
+            else:
+                self.log(_('SOCKS proxy %s:%d appears operational') % self.options.socks)
+            # this should be --use-tor, but:
+            # 1. that is available only in undetermined versions of GPG 2.1.x
+            # 2. it is not available in GPG 1.x legacy, which we still support
+            # 3. it is actually a flag to dirmngr, not gpg, so it
+            # requires writing to a new config file
+            ks_opts = 'no-auto-key-retrieve,no-try-dns-srv,http-proxy=socks5-hostname://%s:%d' % self.options.socks
+            self.tmpkeyring.context.set_option('keyserver-options', ks_opts)
         # copy the gpg.conf from the real keyring
         try:
             self.log(_('copying your gpg.conf in temporary keyring'))
@@ -591,6 +629,12 @@ Sign all identities? [y/N] \
 expects an EmailFactory email, but will not mail if nomail is set"""
             if self.options.smtpserver is not None and not self.options.nomail:
                 if self.options.dryrun: return True
+                # no test, because we'd need to ship a socks server
+                # we assume pysocks is correctly tested, basically:
+                # https://github.com/Anorov/PySocks
+                if self.options.socks:
+                    socks.setdefaultproxy(socks.SOCKS5, *self.options.socks)
+                    socks.wrapmodule(smtplib)
                 if self.options.tls:
                     server = smtplib.SMTP_SSL()
                 else:
@@ -600,23 +644,28 @@ expects an EmailFactory email, but will not mail if nomail is set"""
                 # server.connect() here and display a meaningful message to stderr.
                 try:
                     (code, srvmsg) = server.connect(self.options.smtpserver)
-                except (socket.error, socket.timeout) as e:
+                except (socket.error, socket.timeout, socks.SOCKS5Error) as e:
                     self.abort(_('Error connecting to SMTP server %s: %s') % (self.options.smtpserver, e))
                 if code != 220:
                     self.abort(_('Unexpected SMTP server error while talking to %s, code: %s (%s)') % (self.options.smtpserver, code, srvmsg))
-                try:
-                    server.starttls()
-                except smtplib.SMTPException:
-                    self.warn(_('SMTP server does not support STARTTLS'))
-                    if self.options.smtpuser:
-                        self.abort(_('aborting authentication as credentials would have been sent in clear text'))
+                if not self.options.tls:
+                    try:
+                        server.starttls()
+                    except smtplib.SMTPException:
+                        self.warn(_('SMTP server does not support STARTTLS'))
+                        if self.options.smtpuser:
+                            self.abort(_('aborting authentication as credentials would have been sent in clear text'))
                 if self.options.smtpuser:
                     if not self.options.smtppass:
                         self.options.smtppass = self.prompt_pass(_('enter SMTP password for server %s: ') % self.options.smtpserver)
                     server.login(self.options.smtpuser, self.options.smtppass)
-                server.sendmail(msg.mailfrom.encode('utf-8'), msg.mailto.encode('utf-8'), msg.as_string().encode('utf-8'))
+                try:
+                    server.sendmail(msg.mailfrom.encode('utf-8'), msg.mailto.encode('utf-8'), msg.as_string().encode('utf-8'))
+                except smtplib.SMTPException as e:
+                    self.warn(_('failed to send email: %s') % e)
+                else:
+                    self.warn(_('sent message through SMTP server %s to %s') % (self.options.smtpserver, msg.mailto))
                 server.quit()
-                self.warn(_('sent message through SMTP server %s to %s') % (self.options.smtpserver, msg.mailto))
                 return True
             elif not self.options.nomail:
                 if self.options.dryrun: return True
